@@ -18,7 +18,8 @@ class s2py():
             "x-csrftoken": "a",
             "x-requested-with": "XMLHttpRequest",
             "Cookie": "scratchcsrftoken=a;scratchlanguage=en;",
-            "referer": "https://scratch.mit.edu"
+            "referer": "https://scratch.mit.edu",
+            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.101 Safari/537.36"
         }
         try:
             data = json.dumps({
@@ -27,8 +28,8 @@ class s2py():
             })
             request = requests.post(
                 'https://scratch.mit.edu/login/', data=data, headers=self.headers)
-            sessionId = re.search(
-                '\"(.*)\"', request.headers['Set-Cookie']).group()
+            sessionId = re.search('\"(.*)\"', request.headers['Set-Cookie']).group()
+            
         except AttributeError:
             sys.exit('Error: Invalid credentials. Authentication failed.')
         else:
@@ -157,5 +158,5 @@ class s2py():
         })
 
 
-def sendPackets(self, packet):
+def sendPacket(packet):
     ws.send(json.dumps(packet) + '\n')
